Reference - XTS Client API Documentation

# Reference

- This is a python client package for XTS API. XTS is product from Symphony Fintech Solutions Pvt. Ltd..The original documentation for XTS Clinet is linked here.

- This package is a derivative work of the original package written by Symphony Fintech Solutions Pvt. Ltd..

- Link for original GitHub Repository. It takes inspirations from the original, however it differs in the implimentation.

- Link to pypiserver for hosting the package locally.

#### Search

From here you can search these documents. Enter your search terms below.

#### Keyboard Shortcuts

Keys | Action
--- | ---
`?` | Open this help
`n` | Next page
`p` | Previous page
`s` | Search